REBOL [
   Title:   "Convert currencies"
   Author:  "Dick Whiting"
   Email:   dwhiting@europa.com
   Date:    07-Oct-1998
   File:    %convert.r
   Purpose: {
      Convert one currency to another
   }
   Comment: {

      Reads the currency table produced by bldrates.r          
      Converts first to second. 

      Name is hardcoded as %rates.table
      
      Invoke script with args of: 

         amt/A currency1/A currency2/A [PIPE/S pipename/A]

      If run with a fourth argument of "PIPE" then writes a message
      to the fifth argument which should be PIPE:some.pipe.name

   }
]
c2d: func [str] [

     if not found? find str "." [insert tail str ".00"]
     make decimal! str

]

round: func [num digits] [
      t1: make decimal! 0.0
      t1: (num + (5 / (10 ** (digits + 1)))) * (10 ** digits)
      t1: (t1 - (t1 // 1)) / (10 ** digits)
]

if pick rebol/args 1 [
   amt:     pick rebol/args 1
   curr1:   pick rebol/args 2
   curr2:   pick rebol/args 3
   mode:    pick rebol/args 4
]
else [
   prin   "Enter amount: "
   amt:   input

   prin   "Enter FROM currency: "
   curr1: input

   prin   "Enter TO currency: "
   curr2: input

   mode:  "NONE"

]
   
if mode = "PIPE" [
   pipe: make file! pick rebol/args 5
]

rtabl: load %rates.table

name1: select rtabl curr1
exch1: select rtabl name1
name2: select rtabl curr2
exch2: select rtabl name2

nex1: c2d exch1
nex2: c2d exch2
namt: c2d amt

if all [(curr1 <> "USD") (curr2 <> "USD")] [amt2: (namt * nex1) / nex2]
else [
   if (curr1 = "USD") [amt2: namt / nex2]
   else [amt2: namt * nex1]
]

amt2: round amt2 2

if (mode = "PIPE") [
   write pipe reduce [namt curr1 "=" amt2 curr2]
   write pipe newline
   write pipe "DONE"
   quit
]
else [
   print [namt curr1 "=" amt2 curr2]
   halt
]

